# generated by datamodel-codegen:
#   filename:  image-layout-schema.json
#   timestamp: 2024-12-04T11:33:36+00:00

from __future__ import annotations

from enum import Enum

from pydantic import BaseModel, Field


class ImageLayoutVersion(Enum):
    field_1_0_0 = '1.0.0'


class OCIImageLayout(BaseModel):
    imageLayoutVersion: ImageLayoutVersion = Field(
        ..., description='version of the OCI Image Layout (in the oci-layout file)'
    )




import hashlib


class HashingWriter:
    def __init__(self, base_writer, hash_func=None):
        self.base_writer = base_writer
        self.hash_func = hash_func or hashlib.sha256()

    def write(self, data: bytes):
        self.hash_func.update(data)
        return self.base_writer.write(data)
    
    def tell(self):
        return self.base_writer.tell()

    def close(self):
        self.base_writer.close()


def get_file_hash(path) -> str:
    h = hashlib.sha256()
    with open(path, "rb") as f:
        while chunk := f.read(4096):
            h.update(chunk)
    return h.hexdigest()


if __name__ == "__main__":
    print("?")




from typing import Annotated, Any, Dict, List
from pydantic import AnyUrl, Field

MediaType = Annotated[str, Field(
        ...,
        pattern=r'^[A-Za-z0-9][A-Za-z0-9!#$&^_.+-]{0,126}/[A-Za-z0-9][A-Za-z0-9!#$&^_.+-]{0,126}$'
    )]


Digest = Annotated[str, Field(
        ...,
        pattern=r'^[a-z0-9]+(?:[+._-][a-z0-9]+)*:[a-zA-Z0-9=_-]+$',
        description="the cryptographic checksum digest of the object, in the pattern '<algorithm>:<encoded>'",
    )]


Urls = Annotated[List[AnyUrl],Field(
        ..., description='a list of urls from which this object may be downloaded'
    )]


NonEmptyString = Annotated[str, Field(..., pattern=r".{1,}")]


MapStringString = Annotated[Dict[NonEmptyString, str], Field(...)]


MapStringObject = Annotated[Dict[NonEmptyString, Any], Field(...)]


Int8 = Annotated[int, Field(ge=-128, le=127)]


Int64 = Annotated[int, Field(ge=-9223372036854776000, le=9223372036854776000)]


Base64 = Annotated[str, Field()]


Annotations = Annotated[MapStringString, Field()]
